/*
 * Copyright (c) 2005
 *    Christian Biere <christianbiere@gmx.de> All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the authors nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHORS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef SERVER_HEADER_FILE
#define SERVER_HEADER_FILE

#include "common.h"

#include "connection.h"

/* XXX: "server" is really a poor name for this */
typedef struct server server_t;

server_t *server_new(void);

typedef void (* server_periodic_cb_t)(server_t *, time_t); 
typedef void (* server_process_cb_t)(server_t *, pid_t); 

struct server {
  void  (* mainloop)	(server_t *) NON_NULL;
  int   (* error)	(server_t *, const char *, const char *, int) NON_NULL;
  int   (* add_client)	(server_t *, connection_t *) NON_NULL;
  void  (* watch_client)(server_t *, connection_t *, connection_event_t);
  void  (* watch_process)(server_t *, pid_t, server_process_cb_t);
  void  (* set_periodic_cb) (server_t *, server_periodic_cb_t);
  void  (* set_timeout) (server_t *, unsigned long);
  void  (* destruct)	(server_t *) NON_NULL;
};

/* vi: set ai et sts=2 sw=2 cindent: */
#endif /* SERVER_HEADER_FILE */
